Calculating values of determinant- and trace-based components of Generalized D-, DP-, L- and LP- criteria for an output of a search object, with model and control parameters set in a mood object.
criteria.values.G(search.obj, mood.obj, eps = 10^-23)List of the calculated values:
df pure error degrees of freedom
Ds Ds-criterion value, intercept excluded
DP DPs-criterion value, intercept excluded
LoFD LoF(D)-criterion value from the GD-criterion
LoFDP LoF(DP)-criterion value from the GDP-criterion
biasD bias(D)-criterion value from the GD-criterion
Ls Ls-criterion value, intercept excluded
LP LPs-criterion value, intercept excluded
LoFL LoF(L)-criterion value from the GL-criterion
LoFLP LoF(LP)-criterion value from the GLP-criterion
biasL bias(L)-criterion value from the GL-criterion
Output of the `Search' function
Output of the `mood' function
Computational tolerance, default 10^-20