Calculating values of determinant- and trace-based components of MSE(D)- and MSE(L)- criteria for an output of a search object, with model and control parameters set in a mood object.
criteria.values.mse(search.obj, mood.obj, eps = 10^-20, Biter = 1000)List of the calculated values:
df pure error degrees of freedom
Ds Ds-criterion value, intercept excluded
DP DPs-criterion value, intercept excluded
LoFDP LoF(DP)-criterion value
mseD mse(D)-criterion value, obtained via MC sampling
mseP mse(D)-criterion value, obtained using point prior
L L-criterion value, intercept excluded
LP LP-criterion value, intercept excluded
LoFLP LoF(LP)-criterion value
mseL mse(L)-criterion value
Output of the `Search' function
Output of the `mood' function
Computational tolerance, default 10^-20
MC sample size for evaluating the mse(D)-component